@@ -18,12 +18,12 @@
 import os
 import sys
 
-from PyQt4.QtCore import QDir
-from PyQt4.QtCore import QFileInfo
-from PyQt4.QtCore import QSettings
+from PyQt5.QtCore import QDir
+from PyQt5.QtCore import QFileInfo
+from PyQt5.QtCore import QSettings
 
 from ninja_ide import resources
-from ninja_ide.dependencies import pep8mod
+from ninja_ide.dependencies import pycodestylemod
 
 
 ###############################################################################
@@ -38,8 +38,8 @@ OS_KEY = "Ctrl"
 FONT_FAMILY = 'Monospace'
 FONT_SIZE = 11
 if sys.platform == "darwin":
-    from PyQt4.QtGui import QKeySequence
-    from PyQt4.QtCore import Qt
+    from PyQt5.QtGui import QKeySequence
+    from PyQt5.QtCore import Qt
 
     FONT_FAMILY = 'Monaco'
     FONT_SIZE = 11
@@ -96,7 +96,7 @@ NOTIFY_UPDATES = True
 HIDE_TOOLBAR = False
 SHOW_STATUS_NOTIFICATIONS = True
 
-PYTHON_PATH = "python"
+PYTHON_PATH = "python3"
 PYTHON_PATH_CONFIGURED_BY_USER = False
 EXECUTION_OPTIONS = ""
 
@@ -105,14 +105,14 @@ PROFILES = {}
 TOOLBAR_ITEMS = [
     "new-file", "new-project", "open-file", "open-project", "save-file",
     "separator", "splitv", "splith", "follow-mode", "separator",
-    "cut", "copy", "paste", "separator",
+    "separator",
     "run-project", "run-file", "stop", "separator",
 ]
 
 TOOLBAR_ITEMS_DEFAULT = [
     "new-file", "new-project", "open-file", "open-project", "save-file",
     "separator", "splitv", "splith", "follow-mode", "separator",
-    "cut", "copy", "paste", "separator",
+    "separator",
     "run-project", "run-file", "stop", "separator",
 ]
 
@@ -131,10 +131,11 @@ ALLOW_WORD_WRAP = False
 INDENT = 4
 # by default Unix (\n) is used
 USE_PLATFORM_END_OF_LINE = False
-MARGIN_LINE = 80
+MARGIN_LINE = [79]
 SHOW_MARGIN_LINE = True
 REMOVE_TRAILING_SPACES = True
-SHOW_TABS_AND_SPACES = True
+SHOW_TABS_AND_SPACES = False
+CURSOR_WIDTH = 10
 
 BRACES = {'{': '}',
           '[': ']',
@@ -217,7 +218,7 @@ LANGS = []
 SHOW_PROJECT_EXPLORER = True
 SHOW_SYMBOLS_LIST = True
 SHOW_WEB_INSPECTOR = False
-SHOW_ERRORS_LIST = False
+SHOW_ERRORS_LIST = True
 SHOW_MIGRATION_LIST = True
 
 #Symbols handler per language (file extension)
@@ -307,8 +308,8 @@ def use_platform_specific_eol():
 def pep8mod_refresh_checks():
     """
     Force to reload all checks in pep8mod.py
-    """
-    pep8mod.refresh_checks()
+#     """
+#     pep8mod.refresh_checks()
 
 
 def pep8mod_add_ignore(ignore_code):
@@ -318,7 +319,7 @@ def pep8mod_add_ignore(ignore_code):
         pep8mod_add_ignore('W191')
         'W1919': 'indentation contains tabs'
     """
-    pep8mod.options.ignore.append(ignore_code)
+#     pep8mod.options.ignore.append(ignore_code)
 
 
 def pep8mod_remove_ignore(ignore_code):
@@ -328,16 +329,16 @@ def pep8mod_remove_ignore(ignore_code):
         pep8mod_remove_ignore('W191')
         'W1919': 'indentation contains tabs'
     """
-    if ignore_code in pep8mod.options.ignore:
-        pep8mod.options.ignore.remove(ignore_code)
+#     if ignore_code in pep8mod.options.ignore:
+#         pep8mod.options.ignore.remove(ignore_code)
 
 
 def pep8mod_update_margin_line_length(new_margin_line):
     """
     Patch pep8mod.py to update the margin line length with a new value
     """
-    pep8mod.MAX_LINE_LENGTH = new_margin_line
-    pep8mod.options.max_line_length = new_margin_line
+#     pep8mod.MAX_LINE_LENGTH = new_margin_line
+#     pep8mod.options.max_line_length = new_margin_line
 
 ###############################################################################
 # LOAD SETTINGS
@@ -347,6 +348,7 @@ def pep8mod_update_margin_line_length(new_margin_line):
 def load_settings():
     qsettings = QSettings(resources.SETTINGS_PATH, QSettings.IniFormat)
     #Globals
+    global CURSOR_WIDTH
     global TOOLBAR_AREA
     global LANGUAGE
     global SHOW_START_PAGE
@@ -402,7 +404,7 @@ def load_settings():
     TOOLBAR_AREA = qsettings.value('preferences/general/toolbarArea', 1,
                                    type=int)
     LANGUAGE = qsettings.value('preferences/interface/language', '',
-                               type='QString')
+                               type=str)
     SHOW_START_PAGE = qsettings.value(
         'preferences/general/showStartPage', True, type=bool)
     CONFIRM_EXIT = qsettings.value('preferences/general/confirmExit',
@@ -411,11 +413,11 @@ def load_settings():
     NOTIFY_UPDATES = qsettings.value(
         'preferences/general/notifyUpdates', True, type=bool)
     PYTHON_PATH = qsettings.value('preferences/execution/pythonPath',
-                                  'python', type='QString')
+                                  'python', type=str)
     PYTHON_PATH_CONFIGURED_BY_USER = qsettings.value(
         'preferences/execution/pythonPathConfigured', False, type=bool)
     NINJA_SKIN = qsettings.value('preferences/theme/skin',
-                                 'Default', type='QString')
+                                 'Default', type=str)
     profileDict = dict(qsettings.value('ide/profiles', {}))
     for key in profileDict:
         profile_list = list(profileDict[key])
@@ -440,13 +442,13 @@ def load_settings():
     #EXECUTION OPTIONS
     EXECUTION_OPTIONS = qsettings.value(
         'preferences/execution/executionOptions',
-        defaultValue='', type='QString')
+        defaultValue='', type=str)
     extensions = [item for item in list(qsettings.value(
         'preferences/general/supportedExtensions', []))]
     if extensions:
         SUPPORTED_EXTENSIONS = extensions
     WORKSPACE = qsettings.value(
-        'preferences/general/workspace', "", type='QString')
+        'preferences/general/workspace', "", type=str)
     #Editor
     SHOW_MINIMAP = qsettings.value(
         'preferences/editor/minimapShow', False, type=bool)
@@ -460,13 +462,12 @@ def load_settings():
 
     USE_PLATFORM_END_OF_LINE = qsettings.value(
         'preferences/editor/platformEndOfLine', False, type=bool)
-    MARGIN_LINE = qsettings.value('preferences/editor/marginLine', 80,
-                                  type=int)
+    MARGIN_LINE = qsettings.value('preferences/editor/marginLine', [79])
     pep8mod_update_margin_line_length(MARGIN_LINE)
     REMOVE_TRAILING_SPACES = qsettings.value(
         'preferences/editor/removeTrailingSpaces', True, type=bool)
     SHOW_TABS_AND_SPACES = qsettings.value(
-        'preferences/editor/showTabsAndSpaces', True, type=bool)
+        'preferences/editor/showTabsAndSpaces', False, type=bool)
     USE_TABS = qsettings.value('preferences/editor/useTabs', False, type=bool)
     if USE_TABS:
         pep8mod_add_ignore("W191")
@@ -478,7 +479,7 @@ def load_settings():
     UNDERLINE_NOT_BACKGROUND = qsettings.value(
         'preferences/editor/errorsUnderlineBackground', True, type=bool)
     font_family = qsettings.value(
-        'preferences/editor/fontFamily', "", type='QString')
+        'preferences/editor/fontFamily', "", type=str)
     if font_family:
         FONT_FAMILY = font_family
     font_size = qsettings.value('preferences/editor/fontSize', 0, type=int)
@@ -502,6 +503,8 @@ def load_settings():
         'preferences/editor/centerOnScroll', True, type=bool)
     parentheses = qsettings.value('preferences/editor/parentheses', True,
                                   type=bool)
+    CURSOR_WIDTH = qsettings.value('preferences/editor/cursorWidth', 10, type=int)
+
     if not parentheses:
         del BRACES['(']
     brackets = qsettings.value('preferences/editor/brackets', True, type=bool)
@@ -526,7 +529,7 @@ def load_settings():
     SHOW_WEB_INSPECTOR = qsettings.value(
         'preferences/interface/showWebInspector', False, type=bool)
     SHOW_ERRORS_LIST = qsettings.value(
-        'preferences/interface/showErrorsList', False, type=bool)
+        'preferences/interface/showErrorsList', True, type=bool)
     SHOW_MIGRATION_LIST = qsettings.value(
         'preferences/interface/showMigrationList', True, type=bool)
     #Bookmarks and Breakpoints
